Function validate
Source pub fn validate(getopt: getopt) -> Result<getopt>
Validate parsed options in strict mode.
Success
If strict mode validation passes, unchanged argument wrapped in Result
is returned.
Errors
Returns Err if option not listed in optstring is encountered or
required argument for an option is missing.